controllers

package
v0.0.43 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2024 License: Apache-2.0 Imports: 32 Imported by: 0

Documentation

Index

Constants

const (
	IPv4InterfaceArpProxySysctlTemplate   string = "net.ipv4.conf.%s.proxy_arp"
	IPv4InterfaceDelayProxySysctlTemplate string = "net.ipv4.neigh.%s.proxy_delay"
)

Variables

This section is empty.

Functions

func DeleteMasquerade

func DeleteMasquerade(ipmasq *networkv1alpha1.Masquerade) error

func EnableMasquerade

func EnableMasquerade(ipmasq *networkv1alpha1.Masquerade) error

func EqualCIDR

func EqualCIDR(a, b *net.IPNet) bool

Types

type NetworkAttachmentChangelog

type NetworkAttachmentChangelog struct {
	// contains filtered or unexported fields
}

type NetworkAttachmentReconciler

type NetworkAttachmentReconciler struct {
	client.Client
	Scheme *runtime.Scheme
}

NetworkAttachmentReconciler reconciles a Network object

func (*NetworkAttachmentReconciler) DiffNetwork

func (r *NetworkAttachmentReconciler) DiffNetwork(ctx context.Context, req ctrl.Request) error

func (*NetworkAttachmentReconciler) Reconcile

func (*NetworkAttachmentReconciler) SetupWithManager

func (r *NetworkAttachmentReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager sets up the controller with the Manager.

type NetworkReconciler

type NetworkReconciler struct {
	client.Client
	Scheme *runtime.Scheme
}

NetworkReconciler reconciles a Network object

func (*NetworkReconciler) Reconcile

func (r *NetworkReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)

Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. TODO(user): Modify the Reconcile function to compare the state specified by the Network object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.

For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.13.0/pkg/reconcile

func (*NetworkReconciler) SetupWithManager

func (r *NetworkReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager sets up the controller with the Manager.

type VirtualMachineReconciler

type VirtualMachineReconciler struct {
	client.Client
	Scheme *runtime.Scheme
}

VirtualMachineReconciler makes sure the VM has a correct mac address on the switch

func (*VirtualMachineReconciler) Reconcile

func (*VirtualMachineReconciler) SetupWithManager

func (r *VirtualMachineReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager sets up the controller with the Manager.

Jump to