Documentation
¶
Index ¶
- Constants
- func CreateNetwork(ctx context.Context, spec *networkv1alpha1.NetworkAttachmentSpec) error
- func DeleteMasquerade(ipmasq *networkv1alpha1.Masquerade) error
- func DeleteNetwork(ctx context.Context, spec *networkv1alpha1.NetworkAttachmentSpec) error
- func EnableMasquerade(ipmasq *networkv1alpha1.Masquerade) error
- func EqualCIDR(a, b *net.IPNet) bool
- func NewNetworkAttachment(hostname string, n *networkv1alpha1.Network, req ctrl.Request) (*networkv1alpha1.NetworkAttachment, error)
- type NetworkAttachmentChangelog
- type NetworkAttachmentReconciler
- type NetworkReconciler
- type VirtualMachineReconciler
Constants ¶
const ( IPv4InterfaceArpProxySysctlTemplate string = "net.ipv4.conf.%s.proxy_arp" IPv4InterfaceDelayProxySysctlTemplate string = "net.ipv4.neigh.%s.proxy_delay" )
Variables ¶
This section is empty.
Functions ¶
func CreateNetwork ¶
func CreateNetwork(ctx context.Context, spec *networkv1alpha1.NetworkAttachmentSpec) error
func DeleteMasquerade ¶
func DeleteMasquerade(ipmasq *networkv1alpha1.Masquerade) error
func DeleteNetwork ¶
func DeleteNetwork(ctx context.Context, spec *networkv1alpha1.NetworkAttachmentSpec) error
func EnableMasquerade ¶
func EnableMasquerade(ipmasq *networkv1alpha1.Masquerade) error
func NewNetworkAttachment ¶
func NewNetworkAttachment(hostname string, n *networkv1alpha1.Network, req ctrl.Request) (*networkv1alpha1.NetworkAttachment, error)
Types ¶
type NetworkAttachmentChangelog ¶
type NetworkAttachmentChangelog struct {
// contains filtered or unexported fields
}
type NetworkAttachmentReconciler ¶
NetworkAttachmentReconciler reconciles a Network object
func (*NetworkAttachmentReconciler) DiffNetwork ¶
func (*NetworkAttachmentReconciler) SetupWithManager ¶
func (r *NetworkAttachmentReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type NetworkReconciler ¶
NetworkReconciler reconciles a Network object
func (*NetworkReconciler) Reconcile ¶
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. TODO(user): Modify the Reconcile function to compare the state specified by the Network object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.13.0/pkg/reconcile
func (*NetworkReconciler) SetupWithManager ¶
func (r *NetworkReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type VirtualMachineReconciler ¶
VirtualMachineReconciler makes sure the VM has a correct mac address on the switch
func (*VirtualMachineReconciler) SetupWithManager ¶
func (r *VirtualMachineReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.